@@ -551,6 +551,21 @@ sub doFilter {
 	return grep { !$TL->newValue($_)->isPcPortable() } @$values;
 }
 
+# -----------------------------------------------------------------------------
+# Tripletail::Validator::Filter::DomainName - DomainNameフィルタ
+# -----------------------------------------------------------------------------
+package Tripletail::Validator::Filter::DomainName;
+use Tripletail;
+
+use base qw{Tripletail::Validator::Filter};
+
+sub doFilter {
+	my $this   = shift;
+	my $values = shift;
+
+	return grep { !$TL->newValue($_)->isDomainName() } @$values;
+}
+
 # -----------------------------------------------------------------------------
 # Tripletail::Validator::Filter::IpAddress - IpAddressフィルタ
 # -----------------------------------------------------------------------------
